<?php
/*
Plugin Name: WP Lexica
Description: Plugin to create a simple Lexica with dynamic Index and unlimited Entries
Author: Sven Denkert
Author URI: http://www.galiator.de
Plugin URI: http://www.galiator.de/wordpress/wp-lexica/#utm_source=wpadmin&utm_medium=plugin&utm_campaign=wplexica
Version: 0.2
Text Domain: wp-lexica
Domain Path: /languages/
*/

class WP_Lexica {

	/**
	 *
	 */
	private $version	= 0.2;
	private $slug		= 'lexikon';
	private $overview	= 12;
	private $removeStyle= 0;
	private $startPage	= 1;
	private $postId		= 0;
	private $postParent	= 0;

	/**
	 *  Constructor
	 */
	public function __construct() {
		add_action( 'init', array( &$this, 'register_post_type' ) );
		if( is_admin() ) {
			add_action( 'admin_menu', array( $this, 'plugin_menu' ) );
			add_action( 'admin_init', array( $this, 'plugin_settings' ) );
			load_plugin_textdomain( 'wp-lexica', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
		}
		$this->overview		= get_option('wpl-overview');
		$this->startPage	= get_option('wpl-startPage');
		$this->removeStyle	= get_option('wpl-removeStyle');
		$this->slug			= get_post( $this->startPage )->post_name;
	}

	/**
	 * old PHP4 constructor for compatibility
	 */
	public function WP_Lexica() {
		$this->__construct();
	}

	/**
	 * creating menu under "settings"
	 */
	public function plugin_menu() {
		add_options_page( 'WP Lexica', __( 'WP Lexica', 'wp-lexica' ), 'manage_options',
				'wpl-unique-identifier', array( $this, 'plugin_options' ) );
	}

	/**
	 *
	 */
	function plugin_settings() {
		register_setting( 'wpl-option-group', 'wpl-startPage' );
		register_setting( 'wpl-option-group', 'wpl-overview' );
		register_setting( 'wpl-option-group', 'wpl-removeStyle' );
	}

	/**
	 *
	 */
	public function add_style() {
		return;	// at the moment
		if( $this->removeStyle ) {
			return;
		}
		wp_register_style(
			'wp-lexica',
			plugins_url( '/style.css', __FILE__ ),
	  		array(),
			$this->version
		);
	  	wp_enqueue_style( 'wp-lexica' );
	}

	/**
	 * option page at admin panel
	 */
	public function plugin_options() {
		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}
		?>
		<div class="wrap">
			<?php screen_icon(); ?>
			<h2><?php echo __( 'WP Lexica Settings', 'wp-lexica' ); ?></h2>
			<form method="post" action="options.php">
				<?php
				settings_fields( 'wpl-option-group' );
				do_settings_sections( 'wpl-option-group' );
				?>
				<div style="float:right;width:55%">
					<h3><?php echo __( 'Instructions', 'wp-lexica' ); ?></h3>
					<?php echo __( 'How to use', 'wp-lexica' ); ?>
				</div>
				<div style="clear:left;height:30px;"></div>
				<h3 style="float: left; width: 30%;margin:0;"><?php echo __( 'ID of Startpage (from pages)', 'wp-lexica' ); ?></h3>
				<input style="float: left; width: 10%;" type="text" name="wpl-startPage" value="<?php echo get_option('wpl-startPage'); ?>" />
				<h3 style="clear: left; float: left; width: 30%;margin:0;"><?php echo __( 'Count of latest entries on start page', 'wp-lexica' ); ?></h3>
				<input style="float: left; width: 10%;" type="text" name="wpl-overview" value="<?php echo get_option('wpl-overview'); ?>" />
				<!--<h3 style="clear: left; float: left; width: 30%;margin:0;"><?php echo __( 'Do not load the WP Lexica stylesheet', 'wp-lexica' ); ?></h3>-->
				<input type="hidden" name="wpl-removeStyle" value="0" />
				<!--<input style="float:left;" type="checkbox" name="wpl-removeStyle" value="1" <?php echo get_option('wpl-removeStyle')?'checked="checked"':''; ?> />-->
				<div style="clear:left;"></div>
				<?php submit_button(); ?>
			</form>
		</div>
		<?php
	}

	/**
	 * register post type for lexica
	 */
	public function register_post_type() {
		register_post_type( 'lexica',
			array(
				'labels' => array(
					'name'				=> __( 'WP Lexica', 'wp-lexica' ),
					'singular_name'		=> __( 'Term', 'wp-lexica' ),
					'add_new'			=> __( 'Add New', 'wp-lexica' ),
					'add_new_item'		=> __( 'Add New Term', 'wp-lexica' ),
					'edit'				=> __( 'Edit', 'wp-lexica' ),
					'edit_item'			=> __( 'Edit Term', 'wp-lexica' ),
					'new_item'			=> __( 'New Term', 'wp-lexica' ),
					'view'				=> __( 'View', 'wp-lexica' ),
					'view_item'			=> __( 'View Term', 'wp-lexica' ),
					'search_items'		=> __( 'Search Term', 'wp-lexica' ),
					'not_found'			=> __( 'No Terms found', 'wp-lexica' ),
					'not_found_in_trash'=> __( 'No Terms found in Trash', 'wp-lexica' )
				),
				'public'		=> true,
				'query_var'		=> true,
				'menu_position'	=> 20,
				'capability_type'=> 'post',
				'hierarchical'	=> true,
				'supports'		=> array(
					'title',
					'editor',
					'excerpt',
					'page-attributes'
				),
				'has_archive'	=> false,
				'rewrite'		=> array(
					'slug'		=> $this->slug,
					'with_front'=> false
				)
			)
		);
	}

	/**
	 * only called on pages with a parent?
	 *
	 * @param array $anchestors
	 * @return array
	 */
	public function add_anchestor( $anchestors ) {
		if( get_post_type() == 'lexica' ) {
			$anchestors[] = $this->startPage;
		}
		return array_unique( $anchestors );
	}

	/**
	 * fake parent_post for first level lexica entries
	 * with setting to start page id
	 *
	 * @global WP_Post $post
	 */
	public function add_anchestor_head( ) {
		global $post;
		$this->postId		= $post->ID;
		$this->postParent	= $post->post_parent;
		if( get_post_type() == 'lexica' ) {
			if( $post->post_parent == "0" ) {
				$post->post_parent = $this->startPage;
			}
		}
	}

	/**
	 * evaluate entries shortcode
	 *
	 * @return string
	 * @example [lexica_entries]
	 */
	public function lexica_entries( $params ) {

		global $post;
		// getting posts
		if( $this->postId !== (int)$this->startPage
			&& $post->post_parent === 0
			&& $post->post_type === 'lexica'
		) {
			$loop = new WP_Query( array(
				'post_type'		=> 'lexica',
				'orderby'		=> 'title',
				'order'			=> 'ASC',
				'post_parent'	=> $this->postId,
				'posts_per_page'=> '-1'
			) );
		} else {
			$loop = new WP_Query( array(
				'post_type'		=> 'lexica',
				'orderby'		=> 'date',
				'order'			=> 'DESC',
				'post_parent > 0',
				'posts_per_page'=> $this->overview
			) );
		}

		// output
		$out = '<div id="wp-lexica-directory">';

		while( $loop->have_posts() ) {
			$loop->the_post();
			$postTitle = get_the_title();
			$postLink = get_permalink();
			$out .= '<article>
						<heading><h3><a href="'.$postLink.'" rel="bookmark">'.$postTitle.'</a></h3></heading>
						<p>'.get_the_excerpt().'</p>
						<a href="'.$postLink.'" class="readmore"><span>Mehr</span></a>
					</article>';
		}
		$out .='</div>';
		return $out;

	}

	/**
	 * evaluate index shortcode
	 *
	 * @return string
	 * @example [lexica_index]
	 */
	public function lexica_index( $params ) {

		// letter selected?
		$marked = get_permalink( $this->postParent ? $this->postParent : $this->postId );
		//
		$loop = new WP_Query( array(
			'post_type'		=> 'lexica',
			'orderby'		=> 'title',
			'order'			=> 'ASC',
			'posts_per_page'=> '-1',
			'post_parent'	=> '0'
		) );
		$array = array( );
		if( $loop->have_posts() ) : while( $loop->have_posts() ) : $loop->the_post();
				$array[get_the_title()] = get_permalink();
			endwhile;
		endif;

		//
		$out = '<div id="wp-lexica-index">';
		$clean_array = array_unique( $array );
		asort( $clean_array );
		foreach( $clean_array as $index => $link ) {
			if( $marked == $link ) {
				$out .= '<a class="selected "href="'.$link.'"><span>'.$index.'</span></a>';
			} else {
				$out .= '<a "href="'.$link.'"><span>'.$index.'</span></a>';
			}
		}

		$out .='</div>';
		return $out;

	}

};

$MyWpLexica = new WP_Lexica();

//
add_shortcode( 'lexica_index', array( $MyWpLexica, 'lexica_index' ) );
add_shortcode( 'lexica_entries', array( $MyWpLexica, 'lexica_entries' ) );
// wpseo dosn't call get_anchestors?
add_filter( 'wp_seo_get_bc_ancestors', array( $MyWpLexica, 'add_anchestor' ) );
add_filter( 'get_anchestors', array( $MyWpLexica, 'add_anchestor' ) );
add_action( 'wp_head', array( $MyWpLexica, 'add_anchestor_head' ) );
add_action( 'wp_head', array( $MyWpLexica, 'add_style' ) );

